@@ -1,3 +1,3 @@
 from .elements import *
-from .tree_maker_base import ElementTreeMakerBase
+from .tree_maker_base import ElementTreeMaker
 from .implementation import implement_component
